package DefHash::Examples;

our $DATE = '2018-09-10'; # DATE
our $VERSION = '0.002'; # VERSION

1;
# ABSTRACT: Example DefHash hashes

__END__

=pod

=encoding UTF-8

=head1 NAME

DefHash::Examples - Example DefHash hashes

=head1 VERSION

This document describes version 0.002 of DefHash::Examples (from Perl distribution DefHash-Examples), released on 2018-09-10.

=head1 DESCRIPTION

This distribution contains various examples of L<DefHash> hashes files in its
per-dist share dir. It will also serve as a spectest.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/DefHash-Examples>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-DefHash-Examples>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=DefHash-Examples>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<DefHash>

L<Hash::DefHash>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2018, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
